SubscriptionHandle

Struct SubscriptionHandle 

pub struct SubscriptionHandle { /* private fields */ }
Handle for an active document subscription

Drop this handle to unsubscribe from document changes.

Implementations

Source

impl SubscriptionHandle

pub fn is_active(&self) -> bool

Check if the subscription is still active

pub fn cancel(&self)

Cancel the subscription

pub fn poll_changes(&self) -> Vec<DocumentChange>

Drain all pending document changes. Non-blocking.

Only populated when the subscription was opened via PeatNode::subscribe_poll. Always returns an empty Vec for subscriptions opened via PeatNode::subscribe (callback path).